package Sophos::SAVI::Config;

use strict;
use warnings;

sub validate {
    my ($pkg, $p) = @_;

    $p->typedecl("#alwaysoff", sub {$_[3] = 0; $_[5] = 1}, undef);
    my %conf = (
	enabled                 => ['#bool', 1],
	daemon                  => ['#bool', 0],
	datadir                 => ['#file', 'etc/data/sophos'],
	fullsweep               => ['#bool', undef], # SAVI recommends: off
	emulation               => ['#bool', undef], # SAVI default: on
	scan_macros             => ['#bool', undef], # SAVI recommends: off
	scan_templates          => ['#bool', undef], # SAVI default: on
	scan_pe                 => ['#bool', undef], # SAVI default: on
	scan_xls                => ['#bool', undef], # SAVI default: on
	scan_ppt                => ['#bool', undef], # SAVI default: on
	unzipexe                => ['#bool', undef], # GrpArchiveUnpack: on
	ungzip                  => ['#bool', undef], # GrpArchiveUnpack: on
	unarj                   => ['#bool', undef], # GrpArchiveUnpack: on
	uncmz                   => ['#bool', undef], # GrpArchiveUnpack: on
	unrar                   => ['#bool', undef], # GrpArchiveUnpack: on
	untar                   => ['#bool', undef], # GrpArchiveUnpack: on
	unuue                   => ['#bool', undef], # GrpArchiveUnpack: on
	unzip                   => ['#bool', undef], # GrpArchiveUnpack: on
	maxrecurse              => ['#int', undef],  # SAVI default: 16

        # libsavi options:
	GrpArchiveUnpack        => ['#bool', 1],
	GrpSelfExtract          => ['#bool', undef],
	GrpExecutable           => ['#bool', undef],
	GrpInternet             => ['#bool', 1],
	GrpMSOffice             => ['#bool', undef],
	GrpMisc                 => ['#bool', 1],
	GrpDisinfect            => ['#bool', undef],
	GrpClean                => ['#bool', undef],
	GrpSuper                => ['#bool', undef],

	Access                  => ['#bool', undef],
	ActiveMimeHandling      => ['#bool', undef],
	AppleSingle             => ['#bool', undef],
	ArjDecompression        => ['#bool', undef],
        BehaviourSuspicious     => ['#bool', 1    ],
	Bzip2                   => ['#bool', undef],
	CleanBmp                => ['#bool', undef],
	CleanGif                => ['#bool', undef],
	CleanJpeg               => ['#bool', undef],
	CleanLnk                => ['#bool', undef],
	CleanPng                => ['#bool', undef],
	CleanRiff               => ['#bool', undef],
	CleanTiff               => ['#bool', undef],
	CmzDecompression        => ['#bool', undef],
	DecompressBVA5          => ['#bool', undef],
	DeleteAllMacros         => ['#alwaysoff', 0],
	DelVBA5Project          => ['#bool', undef],
        Dmg                     => ['#bool', undef],
	DynamicDecompression    => ['#bool', undef],
	Elf                     => ['#bool', undef],
	Emulation               => ['#bool', undef],
	EnableAutoStop          => ['#bool', 1],
	EnablePdfAutoStop       => ['#bool', 1],
	ExcelFormulaHandling    => ['#bool', undef],
	ExecFileDisinfection    => ['#bool', undef],
	FullMacroSweep          => ['#bool', undef],
	FullPdf                 => ['#bool', undef],
	FullSweep               => ['#bool', undef],
	GZipDecompression       => ['#bool', undef],
	HelpHandling            => ['#bool', undef],
        Hfs                     => ['#bool', undef],
	HqxDecompression        => ['#bool', undef],
	Html                    => ['#bool', undef],
	IgnoreTemplateBit       => ['#bool', undef],
	ISCabinet               => ['#bool', undef],
	ISCabinetFull           => ['#bool', undef],
	ITSS                    => ['#bool', undef],
	Java                    => ['#bool', undef],
	Lha                     => ['#bool', undef],
	LoopBackEnabled         => ['#bool', undef],
	MachO                   => ['#bool', undef],
	MaxRecursionDepth       => ['#int', undef],
	MbinDecompression       => ['#bool', undef],
	Mime                    => ['#bool', undef],
	MSCabinet               => ['#bool', 1],
	MsCompress              => ['#bool', undef],
	NamespaceSupport        => ['#int',  undef],
	Office2001Handling      => ['#bool', undef],
	OF95DecryptHandling     => ['#bool', undef],
	OleDataMsoHandling      => ['#bool', undef],
	OleRawHandling          => ['#bool', undef],
	OleScriptHandling       => ['#bool', undef],
	Ole2FileDisinfection    => ['#bool', undef],
	Ole2Handling            => ['#bool', undef],
	OpenMacRf               => ['#bool', undef],
	OutlookExpress          => ['#bool', undef],
	PalmPilotHandling       => ['#bool', undef],
	Pdf                     => ['#bool', undef],
	PeEmulator              => ['#bool', undef],
	PEHandling              => ['#bool', undef],
	PowerPointEmbeddedHandling      => ['#bool', undef],
	PowerPointMacroHandling => ['#bool', undef],
        ProductGateway          => ['#bool', 1    ],
	ProjectHandling         => ['#bool', undef],
	RarDecompression        => ['#bool', undef],
	Rpm                     => ['#bool', undef],
	Rtf                     => ['#bool', undef],
	ScrapObjectHandling     => ['#bool', undef],
	SfxArchives             => ['#bool', undef],
	SrpStreamHandling       => ['#bool', undef],
	StorageDetOnly          => ['#bool', undef],
	StorageReport		=> ['#bool', undef],
	StorageReportAll	=> ['#bool', undef],
	Stuffit                 => ['#bool', undef],
	TarDecompression        => ['#bool', undef],
	TnefAttachmentHandling  => ['#bool', undef],
    TrueFileTypeDetection   => ['#bool', undef],
	SXLHexIDCustomer        => ['#str', "222ca6da4b7ddf964aae618f967dced8"],
        SXLDNSIP1               => ['#str', undef],
	SXLDNSIP2               => ['#str', undef],
	SXLDNSIP3               => ['#str', undef],
        SXLHexIDMachine         => ['#str', undef],
        SXLServerList           => ['#str', "000102030405060708"],
        SXLTopLevelDomain       => ['#str', "gw.sophosxl.net"],
        SXLLiveProtection       => ['#bool', undef],
	UnixArchive             => ['#bool', undef],
	Upx                     => ['#bool', undef],
	UTF16                   => ['#bool', undef],
	UueDecompression        => ['#bool', undef],
	VBA3Handling            => ['#bool', undef],
	VBA5Handling            => ['#bool', undef],
	Vba5p                   => ['#bool', undef],
	Vbe                     => ['#bool', undef],
	VbFiltering             => ['#bool', undef],
	VisioFileHandling       => ['#bool', undef],
	WordB                   => ['#bool', undef],
    WordText                => ['#bool', undef],
	ZipDecompression        => ['#bool', undef],
	ZipUseChd               => ['#bool', undef],
	Xml                     => ['#bool', undef],
	ISO9660                 => ['#bool', 1],

    );
    for my $key (keys %conf) {
	my $path = "backend#Sophos.$key";
	my ($t, $d) = @{$conf{$key}};
	$p->typedecl($path, $t) if defined $t;
	$p->default($path, $d)  if defined $d;
    }
}

1;
